#ifndef IONIC_BACKPORT_COMPAT_H
#define IONIC_BACKPORT_COMPAT_H

#include <linux/dynamic_debug.h>
#include <linux/printk.h>
#include <linux/sfp.h>

/* SFF8024 defined constants */
enum {
	SFF8024_ID_UNK                  = 0x00,
	SFF8024_ID_SFF_8472             = SFP_PHYS_ID_SFF,
	SFF8024_ID_SFP                  = SFP_PHYS_ID_SFP,
	SFF8024_ID_DWDM_SFP             = 0x0b,
	SFF8024_ID_QSFP_8438            = 0x0c,
	SFF8024_ID_QSFP_8436_8636       = 0x0d,
	SFF8024_ID_QSFP28_8636          = 0x11,

	SFF8024_ENCODING_UNSPEC         = SFP_ENCODING_UNSPEC,
	SFF8024_ENCODING_8B10B          = SFP_ENCODING_8B10B,
	SFF8024_ENCODING_4B5B           = SFP_ENCODING_4B5B,
	SFF8024_ENCODING_NRZ            = SFP_ENCODING_NRZ,
	SFF8024_ENCODING_8472_MANCHESTER= SFP_ENCODING_8472_MANCHESTER,
	SFF8024_ENCODING_8472_SONET     = SFP_ENCODING_8472_SONET,
	SFF8024_ENCODING_8472_64B66B    = SFP_ENCODING_8472_64B66B,
	SFF8024_ENCODING_8436_MANCHESTER= 0x06,
	SFF8024_ENCODING_8436_SONET     = 0x04,
	SFF8024_ENCODING_8436_64B66B    = 0x05,
	SFF8024_ENCODING_256B257B       = SFP_ENCODING_256B257B,
	SFF8024_ENCODING_PAM4           = SFP_ENCODING_PAM4,

	SFF8024_CONNECTOR_UNSPEC        = SFP_CONNECTOR_UNSPEC,
	/* codes 01-05 not supportable on SFP, but some modules have single SC */
	SFF8024_CONNECTOR_SC            = SFP_CONNECTOR_SC,
	SFF8024_CONNECTOR_FIBERJACK     = SFP_CONNECTOR_FIBERJACK,
	SFF8024_CONNECTOR_LC            = SFP_CONNECTOR_LC,
	SFF8024_CONNECTOR_MT_RJ         = SFP_CONNECTOR_MT_RJ,
	SFF8024_CONNECTOR_MU            = SFP_CONNECTOR_MU,
	SFF8024_CONNECTOR_SG            = SFP_CONNECTOR_SG,
	SFF8024_CONNECTOR_OPTICAL_PIGTAIL= SFP_CONNECTOR_OPTICAL_PIGTAIL,
	SFF8024_CONNECTOR_MPO_1X12      = SFP_CONNECTOR_MPO_1X12,
	SFF8024_CONNECTOR_MPO_2X16      = SFP_CONNECTOR_MPO_2X16,
	SFF8024_CONNECTOR_HSSDC_II      = SFP_CONNECTOR_HSSDC_II,
	SFF8024_CONNECTOR_COPPER_PIGTAIL= SFP_CONNECTOR_COPPER_PIGTAIL,
	SFF8024_CONNECTOR_RJ45          = SFP_CONNECTOR_RJ45,
	SFF8024_CONNECTOR_NOSEPARATE    = SFP_CONNECTOR_NOSEPARATE,
	SFF8024_CONNECTOR_MXC_2X16      = SFP_CONNECTOR_MXC_2X16,

	SFF8024_ECC_UNSPEC              = 0x00,
	SFF8024_ECC_100G_25GAUI_C2M_AOC = 0x01,
	SFF8024_ECC_100GBASE_SR4_25GBASE_SR = 0x02,
	SFF8024_ECC_100GBASE_LR4_25GBASE_LR = 0x03,
	SFF8024_ECC_100GBASE_ER4_25GBASE_ER = 0x04,
	SFF8024_ECC_100GBASE_SR10       = 0x05,
	SFF8024_ECC_100GBASE_CR4        = 0x0b,
	SFF8024_ECC_25GBASE_CR_S        = 0x0c,
	SFF8024_ECC_25GBASE_CR_N        = 0x0d,
	SFF8024_ECC_10GBASE_T_SFI       = 0x16,
	SFF8024_ECC_10GBASE_T_SR        = 0x1c,
	SFF8024_ECC_5GBASE_T            = 0x1d,
	SFF8024_ECC_2_5GBASE_T          = 0x1e,
};


#ifndef dynamic_hex_dump
# define dynamic_hex_dump(prefix_str, prefix_type, rowsize,		\
			 groupsize, buf, len, ascii)			\
	do { if (0)							\
		print_hex_dump(KERN_DEBUG, prefix_str, prefix_type,	\
				rowsize, groupsize, buf, len, ascii);	\
	} while (0)
#endif


/* Part number, identifier of asic design */
#define DEVLINK_INFO_VERSION_GENERIC_ASIC_ID    "asic.id"
/* Revision of asic design */
#define DEVLINK_INFO_VERSION_GENERIC_ASIC_REV   "asic.rev"

/* Overall FW version */
#define DEVLINK_INFO_VERSION_GENERIC_FW         "fw"


#endif /* IONIC_BACKPORT_COMPAT_H */
